@@ -243,7 +243,7 @@ add_group_methods <- function()
             wch <- which(sapply(drives, function(drv) drv$properties$name == drive_name))
             if(length(wch) != 1)
                 stop("Invalid drive name", call.=FALSE)
-            return(drives[[1]])
+            return(drives[[wch]])
         }
         op <- if(is.null(drive_id))
             "drive"
